--[[ Use Addon Wide Data Table ]]--
local addonName,addon = ...

--[[ Localise Addon Wide Data Table Sub Tables ]]--
local Translate = addon.Translate

--[[ Make sure we have nUI tables ]]--
nUI_InfoPanels = nUI_InfoPanels or {}

--[[ Set Up nUI InfoPanel Values ]]--
nUI_INFOMODE_DETAILS  = 31;
nUI_INFOPANEL_DETAILS = "nUI_InfoPanel_Details";

--[[ Set Up the Info Panel Table ]]--
nUI_InfoPanels[nUI_INFOPANEL_DETAILS ] =
{	
	enabled   = true,
	desc      = Translate["INFO_PANEL_TEXT"],		-- player friendly name/description of the panel
	label     = Translate["INFO_PANEL_LABEL"],		-- label to use on the panel selection button face
	rotation  = nUI_INFOMODE_DETAILS ,         		-- index or position this panel appears on/in when clicking the selector button
	full_size = true, 								-- this plugin requires the entire info panel port without the button bag
	
	options  =
	{
		enabled  = true,
	},
};

-- functionality to execute once the addon is loaded
function addon:OnAddonLoaded(plugin)  
    if not plugin then return end
    plugin.enabled = addon.nUILoaded and addon.DetailsLoaded
    plugin.active = plugin.enabled
end

-- Accessor for this plugins name
function addon:GetInfoPanelName()
    return nUI_INFOPANEL_DETAILS
end

-- Extra functionality for when the infopanel is resized
function addon:OnResize(plugin, height, width)
end

-- Extra functionality for when the infopanel is disabled
function addon:OnDisable(plugin)
    
    local dap1 = plugin.dap1
    if dap1 then
        dap1:LockInstance(false)
        dap1.baseframe:SetWidth(plugin.baseWidth1)
        dap1.baseframe:SetParent(plugin.baseParent1)
        dap1.rowframe:SetParent(plugin.rowParent1)    
        dap1.baseframe:SetFrameLevel(plugin.baseLevel1)
        dap1.rowframe:SetFrameLevel(plugin.rowLevel1)
        dap1:LockInstance(true)
    end
    
    local dap2 = plugin.dap2
    if dap2 then
        dap2:LockInstance(false)
        dap2.baseframe:SetWidth(plugin.baseWidth2)
        dap2.baseframe:SetParent(plugin.baseParent2)
        dap2.rowframe:SetParent(plugin.rowParent2)    
        dap2.baseframe:SetFrameLevel(plugin.baseLevel2)
        dap2.rowframe:SetFrameLevel(plugin.rowLevel2)
        dap2:LockInstance(true)
    end
    
end

-- Extra functionality for when the infopanel is enabled
function addon:OnEnable(plugin)
    
    local details = _G.Details or nil
    local instance = details and details:GetInstance(1) or nil
    local windows = instance and instance:GetInstanceGroup() or nil

    local dap1 = #windows > 0 and windows[1] or nil
    local dap2 = #windows > 1 and windows[2] or nil

    if dap1 then
        plugin.dap1 = dap1
        plugin.baseHeight1 = dap1.baseframe:GetHeight()
        plugin.baseWidth1 = dap1.baseframe:GetWidth()
        plugin.baseParent1 = dap1.baseframe:GetParent()
        plugin.rowParent1 = dap1.rowframe:GetParent()
        plugin.baseStrata1 = dap1.baseframe:GetFrameStrata()
        plugin.rowStrata1 = dap1.rowframe:GetFrameStrata()
        plugin.baseLevel1 = dap1.baseframe:GetFrameLevel()
        plugin.rowLevel1 = dap1.rowframe:GetFrameLevel()

        dap1:LockInstance(false)
        dap1.baseframe:ClearAllPoints()
        dap1.baseframe:SetParent(plugin.container)
        
        local width = plugin.container:GetWidth()
        if dap2 then
            width = plugin.container:GetWidth() / 2
            dap1.baseframe:SetWidth( width - 5)
        else
            dap1.baseframe:SetWidth(width - 10)
        end
        dap1.baseframe:SetHeight(plugin.container:GetHeight() - 20)
        dap1.baseframe:SetPoint( "BOTTOMLEFT", plugin.container, "BOTTOMLEFT", 0, 10 );	    
        dap1.rowframe:SetParent (dap1.baseframe)
        dap1.rowframe:ClearAllPoints()
        dap1.rowframe:SetAllPoints()
        dap1.baseframe:SetFrameStrata( plugin.container:GetFrameStrata() );
        dap1.baseframe:SetFrameLevel( plugin.container:GetFrameLevel()+1 );
        dap1.rowframe:SetFrameStrata( plugin.container:GetFrameStrata() );
        dap1.rowframe:SetFrameLevel( plugin.container:GetFrameLevel()+1 );    
        dap1:LockInstance(true)
    end
    if dap2 then 
        plugin.dap2 = dap2
        plugin.baseHeight2 = dap2.baseframe:GetHeight()
        plugin.baseWidth2 = dap2.baseframe:GetWidth()
        plugin.baseParent2 = dap2.baseframe:GetParent()
        plugin.rowParent2 = dap2.rowframe:GetParent()
        plugin.baseStrata2 = dap2.baseframe:GetFrameStrata()
        plugin.rowStrata2 = dap2.rowframe:GetFrameStrata()
        plugin.baseLevel2 = dap2.baseframe:GetFrameLevel()
        plugin.rowLevel2 = dap2.rowframe:GetFrameLevel()

        dap2:LockInstance(false)
        dap2.baseframe:ClearAllPoints()
        dap2.baseframe:SetParent(plugin.container)
        local width = plugin.container:GetWidth()
        if dap2 then
            width = plugin.container:GetWidth() / 2
            dap2.baseframe:SetWidth( width - 5)
        else
            dap2.baseframe:SetWidth(width - 10)
        end
        dap2.baseframe:SetHeight(plugin.container:GetHeight() - 20)
        dap2.baseframe:SetPoint( "BOTTOMLEFT", dap1.baseframe, "BOTTOMRIGHT", 0, 10 );	    
        dap2.rowframe:SetParent (dap2.baseframe)
        dap2.rowframe:ClearAllPoints()
        dap2.rowframe:SetAllPoints()
        dap2.baseframe:SetFrameStrata( plugin.container:GetFrameStrata() );
        dap2.baseframe:SetFrameLevel( plugin.container:GetFrameLevel()+1 );
        dap2.rowframe:SetFrameStrata( plugin.container:GetFrameStrata() );
        dap2.rowframe:SetFrameLevel( plugin.container:GetFrameLevel()+1 );    
        dap2:LockInstance(true)
    end
    
end

-- Extra functionality for when the infopanel is selected
function addon:OnSelected(plugin)
    if plugin and plugin.selected and plugin.enabled == true then self:OnEnable(plugin) end
end
